aboutsummaryrefslogtreecommitdiff
path: root/lib/urldata.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/urldata.h')
-rw-r--r--lib/urldata.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/urldata.h b/lib/urldata.h
index 903f47a46..eefa60561 100644
--- a/lib/urldata.h
+++ b/lib/urldata.h
@@ -847,9 +847,9 @@ struct UserDefined {
curl_read_callback fread; /* function that reads the input */
curl_progress_callback fprogress; /* function for progress information */
curl_debug_callback fdebug; /* function that write informational data */
- curl_ioctl_callback ioctl; /* function for I/O control */
+ curl_ioctl_callback ioctrl; /* function for I/O control */
void *progress_client; /* pointer to pass to the progress callback */
- void *ioctl_client; /* pointer to pass to the ioctl callback */
+ void *ioctrl_client; /* pointer to pass to the ioctrl callback */
long timeout; /* in seconds, 0 means no timeout */
long connecttimeout; /* in seconds, 0 means no timeout */
long ftp_response_timeout; /* in seconds, 0 means no timeout */